@echo off

REM *******************************************************
REM		   Robby Roto Compile and Run (RRCAR)
REM 
REM This batch file assembles the Robby Roto source file and verifies that 
REM the binaries are identical by running it in MAME. It also allows special 
REM functions via calling it with parameters (see code remarks below).
REM
REM NOTE: There is no error checking so you have to stop
REM the process manually if something goes wrong.
REM
REM *******************************************************

echo Robby Roto Compile and Run (RRCAR)
echo Version: 20181229 by David E. Turner AKA Commander Dave
echo          dave@commanderdave.com

REM *******************************************************
REM Set the paths and filenames. It is recommended you put the
REM base directory under the c:\users\%username% directory.
REM *******************************************************

REM  Change the two lines below to suit your taste
REM  BE SURE not to have any spaces before or after the path or drive!

SET HardDrive=C:
SET Base_Directory=%HardDrive%\Users\%username%\Google_Drive\APD

SET Source_Name=RR_Disassembly
SET GameName=Robby_Roto
SET Source_Path=%Base_Directory%\%GameName%\Disassembly
SET Zmac_Path=%Base_Directory%\_Programs\Zmac
SET MAME_Path=%Base_Directory%\_Programs\MAME
SET MAME_ROMs=%MAME_Path%\roms\%GameName%
SET Utilities_Path=%Base_Directory%\_Programs\Utilities
SET Scratch_Area=%Utilities_Path%\_Scratch_Area
SET Original_ROM_Path=%Base_Directory%\_Programs\ROMs\%GameName%

REM *******************************************************
REM Check input to batch file to see if it is a special case.
REM	Empty = Compile RR as normal
REM	1 = Just go run RR with no modifications to ROMs
REM	2 = Reset the MAME ROMs to original defaults.
REM *******************************************************

IF [%1]==[] GOTO :compile_Robby_Roto	
IF %1==1 GOTO :run_Robby_Roto
IF %1==2 GOTO :reset_roms

:compile_Robby_Roto

REM *******************************************************
REM Clear the scratch area and change the directory
REM to where the action is...
REM *******************************************************
echo --} Clearing files in scratch directory
del /Q %Scratch_Area%\*.*
cd /D %Scratch_Area%

REM *******************************************************
REM Zmac has many environment and command line options. 
REM This will provide a bit of what the selected options 
REM do. For better descriptions, see the Zmac manual.
REM
REM The simplified Zmac command line is:
REM   zmac -o out-file.hex -x list-file.lst input-file-name.asm
REM
REM Options:
REM   -o       Compiled output file .hex
REM   -m       Expand Macros
REM 
REM The input file name will be taken from the Source_Name 
REM variable and the output will be in the form of the 
REM filename with the extensions .hex and .lst.
REM *******************************************************

echo. 
echo --} Compiling %Source_Name%  
cd %Source_Path%\Include_Files
%Zmac_Path%\zmac -m -o %Source_Path%\%Source_Name%.hex -x %Source_Path%\%Source_Name%.lst %Source_Path%\%Source_Name%.asm  

echo --} Converting .hex to .bin 
pause
copy %Source_Path%\%Source_Name%.hex %Source_Name%.hex >NUL
%Utilities_Path%\hex2bin\hex2bin %Source_Name%.hex 2>NUL >NUL

REM *******************************************************
REM At this point, the source has been assembled in to one
REM large binary file and needs to be split into it's 
REM ten parts: 
REM rotox1.bin rotox2.bin, rotox3.bin, rotox4.bin, rotox5.bin 
REM rotox6.bin rotox7.bin, rotox8.bin, rotox9.bin, rotox10.bin 
REM *******************************************************

echo --} Splitting Binary File 

%Utilities_Path%\fsplit\fsplit.exe -split 4 kb %Source_Name%.bin >NUL

REM *******************************************************
REM Due to a limitation in the splitting program, we have
REM to remove some unnecessary files. The middle four 
REM files are just FF padding put in by the fsplit program.
REM Unforutnaly, there is no option for preventing this (yet)
REM *******************************************************

echo --} Removing unnecessary files created by split program 

del RR_Disassembly_01*.bin_05*.bin >NUL
del RR_Disassembly_01*.bin_06*.bin >NUL
del RR_Disassembly_01*.bin*.bin >NUL
del Gorf_Disassembly_08*.bin >NUL

REM *******************************************************
REM Now we have to rename the assembled binaries 
REM to match Robby Roto ROMS required by MAME
REM *******************************************************

echo --} Renaming binary files for MAME 
 
rename RR_Disassembly_01*.bin rotox1.bin >NUL
rename RR_Disassembly_02*.bin rotox2.bin >NUL
rename RR_Disassembly_03*.bin rotox3.bin >NUL
rename RR_Disassembly_04*.bin rotox4.bin >NUL
rename RR_Disassembly_09*.bin rotox5.bin >NUL
rename RR_Disassembly_10*.bin rotox6.bin >NUL
rename RR_Disassembly_11*.bin rotox7.bin >NUL
rename RR_Disassembly_12*.bin rotox8.bin >NUL
rename RR_Disassembly_12*.bin rotox9.bin >NUL
rename RR_Disassembly_12*.bin rotox10.bin >NUL


echo --} Moving ROM files to MAME area

move rotox??.bin "%MAME_ROMs%" >NUL
echo.
echo --------------------------------------------------
echo --- Press any key to run MAME with new program ---
echo --------------------------------------------------
echo.
pause

REM *******************************************************
REM Run Gorf!
REM *******************************************************
:run_Robby_Roto
cd /D %MAME_Path%
mame64.exe -debug %GameName%
GOTO:eof

REM *******************************************************
REM Reset Gorf ROMs to their defaults
REM *******************************************************

:reset_roms
cd /D %MAME_ROMs%
del gorf*.bin >NUL 2>NUL
del sc01a.bin >NUL 2>NUL
copy %Original_ROM_Path%\Gorf-a.bin Gorf-a.bin >NUL
copy %Original_ROM_Path%\Gorf-b.bin Gorf-b.bin >NUL
copy %Original_ROM_Path%\Gorf-c.bin Gorf-c.bin >NUL
copy %Original_ROM_Path%\Gorf-d.bin Gorf-d.bin >NUL
copy %Original_ROM_Path%\Gorf-e.bin Gorf-e.bin >NUL
copy %Original_ROM_Path%\Gorf-f.bin Gorf-f.bin >NUL
copy %Original_ROM_Path%\Gorf-g.bin Gorf-g.bin >NUL
copy %Original_ROM_Path%\Gorf-h.bin Gorf-h.bin >NUL
copy %Original_ROM_Path%\sc01a.bin sc01a.bin   >NUL
echo --} Gorf ROMs have been reset to defaults
echo.
pause
GOTO:eof